var path = require('path');
var webpack = require('webpack');
var StringReplacePlugin = require("string-replace-webpack-plugin");

module.exports = {
    devtool: 'source-map',
    context: path.resolve(__dirname, './app/js'),
    resolve: {
        alias: {
            "autocomplete": "jquery-ui/ui/widgets/autocomplete.js",
            "dropdown": "bootstrap/js/dropdown.js",
            "modal": "bootstrap/js/modal.js"
        },
        extensions: ['', '.js']
    },
    entry: {
        scripts: "./app.js"
    },
    output: {
        library: 'polyLocator',
        libraryTarget: 'umd',
        publicPath: '/js/',
        path: 'build/',
        filename: "[name].js"
    },
    module: {
        loaders: [
            {
                test: /\.js?$/,
                exclude: /(node_modules|bower_components)/,
                loader: 'babel',
                query: {
                    presets: ['es2015'],
                    plugins: ['add-module-exports']
                }
            },
            {
                test: /\.json?$/,
                exclude: /(node_modules|bower_components)/,
                loader: 'json-loader'
            }
        ]
    },
    plugins: [

        new webpack.DefinePlugin({
            "process.env": {
                NODE_ENV: JSON.stringify(process.env.NODE_ENV || "development")
            }
        }),
        new webpack.ProvidePlugin({
            "$": 'jquery',
            jQuery: 'jquery' // for jQuery plugins
        }),
        new StringReplacePlugin()

    ].concat(process.env.NODE_ENV === "production" ? [

        new webpack.optimize.UglifyJsPlugin({
            compress: {
                warnings: false
            }
        })

    ] : []),
    node: {
        fs: 'empty'
    }
};
